@@ -45,7 +45,7 @@
 #include <openobex/obex_const.h>
 
 #include "plugin.h"
-#include "logging.h"
+#include "log.h"
 #include "obex.h"
 #include "dbus.h"
 #include "mimetype.h"
@@ -171,9 +171,6 @@ static int get_by_type(struct ftp_session *ftp, const char *type)
 	if (g_strcmp0(type, CAP_TYPE) == 0)
 		return obex_get_stream_start(os, capability);
 
-	if (g_strcmp0(type, LST_TYPE) == 0)
-		return obex_get_stream_start(os, ftp->folder);
-
 	path = g_build_filename(ftp->folder, name, NULL);
 	err = obex_get_stream_start(os, path);
 
@@ -261,7 +258,8 @@ static int ftp_chkput(struct obex_session *os, void *user_data)
 	return ret;
 }
 
-static int ftp_put(struct obex_session *os, void *user_data)
+static int ftp_put(struct obex_session *os, obex_object_t *obj,
+						void *user_data)
 {
 	struct ftp_session *ftp = user_data;
 	const char *name = obex_get_name(os);
@@ -301,7 +299,7 @@ static int ftp_setpath(struct obex_session *os, obex_object_t *obj,
 
 	/* Check flag "Backup" */
 	if ((nonhdr[0] & 0x01) == 0x01) {
-		debug("Set to parent path");
+		DBG("Set to parent path");
 
 		if (root)
 			return -EPERM;
@@ -310,18 +308,18 @@ static int ftp_setpath(struct obex_session *os, obex_object_t *obj,
 		set_folder(ftp, fullname);
 		g_free(fullname);
 
-		debug("Set to parent path: %s", ftp->folder);
+		DBG("Set to parent path: %s", ftp->folder);
 
 		return 0;
 	}
 
 	if (!name) {
-		debug("Set path failed: name missing!");
+		DBG("Set path failed: name missing!");
 		return -EINVAL;
 	}
 
 	if (strlen(name) == 0) {
-		debug("Set to root");
+		DBG("Set to root");
 		set_folder(ftp, root_folder);
 		return 0;
 	}
@@ -334,7 +332,7 @@ static int ftp_setpath(struct obex_session *os, obex_object_t *obj,
 
 	fullname = g_build_filename(ftp->folder, name, NULL);
 
-	debug("Fullname: %s", fullname);
+	DBG("Fullname: %s", fullname);
 
 	if (root && obex_get_symlinks(os))
 		err = stat(fullname, &dstat);
@@ -347,7 +345,7 @@ static int ftp_setpath(struct obex_session *os, obex_object_t *obj,
 		if (err == -ENOENT)
 			goto not_found;
 
-		debug("%s: %s(%d)", root ? "stat" : "lstat",
+		DBG("%s: %s(%d)", root ? "stat" : "lstat",
 				strerror(-err), -err);
 
 		goto done;
@@ -370,7 +368,7 @@ not_found:
 
 	if (mkdir(fullname, 0755) <  0) {
 		err = -errno;
-		debug("mkdir: %s(%d)", strerror(-err), -err);
+		DBG("mkdir: %s(%d)", strerror(-err), -err);
 		goto done;
 	}
 
